@@ -34,14 +34,14 @@
 #include <kinputdialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kmenu.h>
-#include <kaction.h>
+#include <QMenu>
+#include <QAction>
 #include <kactionmenu.h>
 #include <kactioncollection.h>
 #include <kmainwindow.h>
 #include <ktoolbar.h>
 #include <krun.h>
-#include <kstandarddirs.h>
+
 #include <kcomponentdata.h>
 #include <kemoticons.h>
 #include <kcodecs.h>
@@ -65,6 +65,7 @@
 #include "wlmchatsessioninkaction.h"
 #ifdef HAVE_GIFLIB
 #include <gif_lib.h>
+#include <QStandardPaths>
 /* old giflib has no GIFLIB_MAJOR, define to avoid cpp warnings */
 #ifndef GIFLIB_MAJOR
 #define GIFLIB_MAJOR 4
@@ -114,14 +115,13 @@ m_sessionID(1)
         setReady (true);
     }
 
-    m_actionNudge = new KAction (KIcon ("preferences-desktop-notification-bell"), i18n ("Send Nudge"), this);
+    m_actionNudge = new QAction (QIcon::fromTheme(QStringLiteral("preferences-desktop-notification-bell")), i18n ("Send Nudge"), this);
     actionCollection ()->addAction ("wlmSendNudge", m_actionNudge);
     connect (m_actionNudge, SIGNAL (triggered(bool)), this,
              SLOT (sendNudge()));
 
-
     m_actionInvite =
-        new KActionMenu (KIcon ("system-users"), i18n ("&Invite"), this);
+        new KActionMenu (QIcon::fromTheme(QStringLiteral("system-users")), i18n ("&Invite"), this);
     actionCollection ()->addAction ("wlmInvite", m_actionInvite);
     m_actionInvite->setDelayed(false);
     connect (m_actionInvite->menu (), SIGNAL (aboutToShow()), this,
@@ -144,7 +144,7 @@ m_sessionID(1)
 #ifdef HAVE_MEDIASTREAMER
     if(userCaps & MSN::VoiceClips)
     {
-        m_actionVoice = new KActionMenu (KIcon ("preferences-desktop-sound"), i18n ("Send &Voice"), this);
+        m_actionVoice = new KActionMenu (QIcon::fromTheme(QStringLiteral("preferences-desktop-sound")), i18n ("Send &Voice"), this);
         actionCollection ()->addAction ("wlmSendVoice", m_actionVoice);
         ms_init();
         m_voiceCardCapture = ms_snd_card_manager_get_default_capture_card(ms_snd_card_manager_get());
@@ -159,7 +159,7 @@ m_sessionID(1)
         connect (m_actionVoice->menu(), SIGNAL (aboutToHide()), this,
                  SLOT (slotSendVoiceStopRec()));
 
-        KAction *stopRec = new  KAction(KIcon("wlm_fakefriend"), i18n("Stop &recording"), actionCollection ());
+        QAction *stopRec = new  QAction(QIcon::fromTheme(QStringLiteral("wlm_fakefriend")), i18n("Stop &recording"), actionCollection ());
         m_actionVoice->addAction (stopRec);
         m_actionVoice->setDelayed(false);
     }
@@ -641,7 +641,7 @@ WlmChatSession::slotSendInk ( const QPixmap & ink)
 void
 WlmChatSession::slotActionInviteAboutToShow ()
 {
-    // We can't simply insert  KAction in this menu bebause we don't know when to delete them.
+    // We can't simply insert  QAction in this menu bebause we don't know when to delete them.
     //  items inserted with insert items are automatically deleted when we call clear
 
     qDeleteAll (m_inviteactions);
@@ -649,7 +649,6 @@ WlmChatSession::slotActionInviteAboutToShow ()
 
     m_actionInvite->menu ()->clear ();
 
-
     QHash < QString, Kopete::Contact * >contactList = account ()->contacts();
     QHash < QString, Kopete::Contact * >::Iterator it, itEnd =
         contactList.end ();
@@ -657,7 +656,7 @@ WlmChatSession::slotActionInviteAboutToShow ()
     {
         if (!members ().contains (it.value ()) && it.value ()->isOnline ())
         {
-            KAction *a =
+            QAction *a =
                 new Kopete::UI::ContactAction (it.value (),
                                                actionCollection ());
 			connect( a, SIGNAL(triggered(Kopete::Contact*,bool)),
@@ -668,7 +667,7 @@ WlmChatSession::slotActionInviteAboutToShow ()
         }
     }
 
-    // We can't simply insert  KAction in this menu bebause we don't know when to delete them.
+    // We can't simply insert  QAction in this menu bebause we don't know when to delete them.
     //  items inserted with insert items are automatically deleted when we call clear
 /*
     m_inviteactions.setAutoDelete(true);
@@ -681,19 +680,18 @@ WlmChatSession::slotActionInviteAboutToShow ()
     {
         if( !members().contains( it.current() ) && it.current()->isOnline() && it.current() != myself() )
         {
-            KAction *a=new KopeteContactAction( it.current(), this,
+            QAction *a=new KopeteContactAction( it.current(), this,
                 SLOT(slotInviteContact(Kopete::Contact*)), m_actionInvite );
             m_actionInvite->insert( a );
             m_inviteactions.append( a ) ;
         }
     }
-//    KAction *b=new KAction( i18n ("Other..."), 0, this, SLOT(slotInviteOtherContact()), m_actionInvite, "actionOther" );
+//    QAction *b=new QAction( i18n ("Other..."), 0, this, SLOT(slotInviteOtherContact()), m_actionInvite, "actionOther" );
 //    m_actionInvite->insert( b );
 //    m_inviteactions.append( b ) ;
 */
 }
 
-
 void
 WlmChatSession::sendNudge ()
 {
@@ -1176,11 +1174,10 @@ WlmChatSession::requestDisplayPicture ()
     }
     if (isReady ())
     {
-        QString newlocation = KGlobal::dirs()->locateLocal("appdata", "wlmpictures/" + QString(SHA1D.replace ('/', '_')));
+        QString newlocation = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "wlmpictures/" + QString(SHA1D.replace ('/', '_'));
         getChatService()->requestDisplayPicture(generateSessionID(), QFile::encodeName(newlocation).constData(),
                                                 contact->getMsnObj().toUtf8().constData());
         setDownloadDisplayPicture (false);
     }
 }
 
-#include "wlmchatsession.moc"
