@@ -27,20 +27,20 @@ class YMSGTransfer;
 */
 class ListTask : public Task
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-	ListTask(Task *parent);
-	~ListTask();
-	
-	bool take(Transfer *transfer);
+    ListTask(Task *parent);
+    ~ListTask();
+
+    bool take(Transfer *transfer) Q_DECL_OVERRIDE;
 
 protected:
-	virtual bool forMe( const Transfer *transfer ) const;
-	void parseBuddyList( YMSGTransfer *transfer );
+    bool forMe(const Transfer *transfer) const Q_DECL_OVERRIDE;
+    void parseBuddyList(YMSGTransfer *transfer);
 
-signals:
-	void gotBuddy(const QString&, const QString&, const QString&);
-	void stealthStatusChanged( const QString&, Yahoo::StealthStatus );
+Q_SIGNALS:
+    void gotBuddy(const QString &, const QString &, const QString &);
+    void stealthStatusChanged(const QString &, Yahoo::StealthStatus);
 };
 
 #endif
