@@ -27,18 +27,18 @@ class YMSGTransfer;
 */
 class MailNotifierTask : public Task
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-	MailNotifierTask(Task *parent);
-	~MailNotifierTask();
-	
-	bool take(Transfer *transfer);
+    MailNotifierTask(Task *parent);
+    ~MailNotifierTask();
+
+    bool take(Transfer *transfer) Q_DECL_OVERRIDE;
 
 protected:
-	virtual bool forMe( const Transfer *transfer ) const;
-	void parseMail( YMSGTransfer *transfer );
-signals:
-	void mailNotify(const QString&, const QString&, int);
+    bool forMe(const Transfer *transfer) const Q_DECL_OVERRIDE;
+    void parseMail(YMSGTransfer *transfer);
+Q_SIGNALS:
+    void mailNotify(const QString &, const QString &, int);
 };
 
 #endif
