@@ -48,35 +48,34 @@
 #include <QPointer>
 
 // KDE Includes
-#include <kdebug.h>
-#include <kaction.h>
+#include "yahoo_protocol_debug.h"
+#include <QAction>
 #include <KActionCollection>
 #include <kdialog.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <krun.h>
-#include <kshortcut.h>
+#include <QKeySequence>
 #include <kmessagebox.h>
 #include <ktemporaryfile.h>
 #include <kio/global.h>
 #include <kio/job.h>
 #include <kio/jobclasses.h>
 #include <kimageio.h>
-#include <kstandarddirs.h>
-#include <kfiledialog.h>
+
 #include <ktoolinvocation.h>
-#include <kicon.h>
+#include <QIcon>
 
 YahooContact::YahooContact( YahooAccount *account, const QString &userId, const QString &fullName, Kopete::MetaContact *metaContact )
 	: Kopete::Contact( account, userId, metaContact )
 {
-	//kDebug(YAHOO_GEN_DEBUG) ;
+	//qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	m_userId = userId;
 	if ( metaContact )
 		m_groupName = metaContact->groups().first()->displayName();
-	m_manager = 0L;
+	m_manager = nullptr;
 	m_account = account;
-	m_YABEntry = 0L;
+	m_YABEntry = nullptr;
 	m_receivingWebcam = false;
 	m_sessionActive = false;
 
@@ -88,20 +87,20 @@ YahooContact::YahooContact( YahooAccount *account, const QString &userId, const
 	if ( m_account->haveContactList() )
 		syncToServer();
 
-	m_webcamDialog = 0L;
-	m_webcamAction = 0L;
-	m_stealthAction = 0L;
-	m_inviteWebcamAction = 0L;
-	m_inviteConferenceAction = 0L;
-	m_profileAction = 0L;
+	m_webcamDialog = nullptr;
+	m_webcamAction = nullptr;
+	m_stealthAction = nullptr;
+	m_inviteWebcamAction = nullptr;
+	m_inviteConferenceAction = nullptr;
+	m_profileAction = nullptr;
 
-	m_buzzAction = 0L;
+	m_buzzAction = nullptr;
 }
 
 YahooContact::~YahooContact()
 {
 	delete m_YABEntry;
-	m_YABEntry = 0L;
+	m_YABEntry = nullptr;
 }
 
 QString YahooContact::userId() const
@@ -119,7 +118,7 @@ void YahooContact::setOnlineStatus(const Kopete::OnlineStatus &status)
 			(status.weight()==0) ? 0 : (status.weight() -1)  ,
 			protocol() ,
 			status.internalStatus()+1000 ,
-			status.overlayIcons() + QStringList("yahoo_stealthed") ,
+			status.overlayIcons() + QStringList(QStringLiteral("yahoo_stealthed")) ,
 			i18n("%1|Stealthed", status.description() ) ) );
 	}
 	else if( !isStealthed && status.internalStatus() > 999 )// Stealthed -> Not Stealthed
@@ -143,18 +142,18 @@ bool YahooContact::stealthed() const
 
 void YahooContact::serialize(QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData)
 {
-	//kDebug(YAHOO_GEN_DEBUG) ;
+	//qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	Kopete::Contact::serialize(serializedData, addressBookData);
 }
 
 void YahooContact::syncToServer()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	if(!m_account->isConnected()) return;
 
 	if ( !m_account->isOnServer(m_userId) && !metaContact()->isTemporary() )
-	{	kDebug(YAHOO_GEN_DEBUG) << "Contact " << m_userId << " doesn't exist on server-side. Adding...";
+	{	qCDebug(YAHOO_PROTOCOL_LOG) << "Contact " << m_userId << " doesn't exist on server-side. Adding...";
 
 		Kopete::GroupList groupList = metaContact()->groups();
 		foreach(Kopete::Group *g, groupList)
@@ -164,14 +163,14 @@ void YahooContact::syncToServer()
 
 void YahooContact::sync(unsigned int flags)
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	if ( !m_account->isConnected() )
 		return;
 
 	if ( !m_account->isOnServer( contactId() ) )
 	{
 		//TODO: Share this code with the above function
-		kDebug(YAHOO_GEN_DEBUG) << "Contact isn't on the server. Adding...";
+		qCDebug(YAHOO_PROTOCOL_LOG) << "Contact isn't on the server. Adding...";
 		Kopete::GroupList groupList = metaContact()->groups();
 		foreach(Kopete::Group *g, groupList)
 			m_account->yahooSession()->addBuddy(m_userId, g->displayName() );
@@ -181,23 +180,22 @@ void YahooContact::sync(unsigned int flags)
 		QString newGroup = metaContact()->groups().first()->displayName();
 		if ( flags & Kopete::Contact::MovedBetweenGroup )
 		{
-			kDebug(YAHOO_GEN_DEBUG) << "contact changed groups. moving on server";
+			qCDebug(YAHOO_PROTOCOL_LOG) << "contact changed groups. moving on server";
 			m_account->yahooSession()->moveBuddy( contactId(), m_groupName, newGroup );
 			m_groupName = newGroup;
 		}
 	}
 }
 
-
 bool YahooContact::isOnline() const
 {
-	//kDebug(YAHOO_GEN_DEBUG) ;
+	//qCDebug(YAHOO_PROTOCOL_LOG) ;
 	return onlineStatus().status() != Kopete::OnlineStatus::Offline && onlineStatus().status() != Kopete::OnlineStatus::Unknown;
 }
 
 bool YahooContact::isReachable()
 {
-	//kDebug(YAHOO_GEN_DEBUG) ;
+	//qCDebug(YAHOO_PROTOCOL_LOG) ;
 	if ( m_account->isConnected() )
 		return true;
 	else
@@ -230,113 +228,112 @@ QString YahooContact::prepareMessage( const QString &messageText )
 	int pos = 0;
 	regExp.setMinimal( true );
 	// find and replace <p>-formattings
-	regExp.setPattern( "<p style=\"([^\"]*)\">(.*)</p>" );
+	regExp.setPattern( QStringLiteral("<p style=\"([^\"]*)\">(.*)</p>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("\\2" ) );
+			newMsg.replace( regExp, QStringLiteral("\\2" ) );
 		}
 	}
 
-
 	// find and replace Bold-formattings
-	regExp.setPattern( "<span([^>]*)font-weight:600([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)font-weight:600([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("<span\\1font-weight:600\\2>\033[1m\\3\033[x1m</span>" ) );
+			newMsg.replace( regExp, QStringLiteral("<span\\1font-weight:600\\2>\033[1m\\3\033[x1m</span>" ) );
 		}
 	}
 
 	// find and replace Underline-formattings
-	regExp.setPattern( "<span([^>]*)text-decoration:underline([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)text-decoration:underline([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("<span\\1text-decoration:underline\\2>\033[4m\\3\033[x4m</span>" ) );
+			newMsg.replace( regExp, QStringLiteral("<span\\1text-decoration:underline\\2>\033[4m\\3\033[x4m</span>" ) );
 		}
 	}
 
 	// find and replace Italic-formattings
-	regExp.setPattern( "<span([^>]*)font-style:italic([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)font-style:italic([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("<span\\1font-style:italic\\2>\033[2m\\3\033[x2m</span>" ) );
+			newMsg.replace( regExp, QStringLiteral("<span\\1font-style:italic\\2>\033[2m\\3\033[x2m</span>" ) );
 		}
 	}
 
 	// find and remove background color formattings (not supported)
-	regExp.setPattern( "<span([^>]*)background-color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)background-color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("<span\\1\\3>\\4</span>" ) );
+			newMsg.replace( regExp, QStringLiteral("<span\\1\\3>\\4</span>" ) );
 		}
 	}
 
 	// find and replace Color-formattings
-	regExp.setPattern( "<span([^>]*)color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("<span\\1\\3>\033[#\\2m\\4\033[#000000m</span>" ) );
+			newMsg.replace( regExp, QStringLiteral("<span\\1\\3>\033[#\\2m\\4\033[#000000m</span>" ) );
 		}
 	}
 
 	// find and replace Font-formattings
-	regExp.setPattern( "<span([^>]*)font-family:([^;\"]*)([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)font-family:([^;\"]*)([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("<span\\1\\3><font face=\"\\2\">\\4</span>" ) );
+			newMsg.replace( regExp, QStringLiteral("<span\\1\\3><font face=\"\\2\">\\4</span>" ) );
 		}
 	}
 
 	// find and replace Size-formattings
-	regExp.setPattern( "<span([^>]*)font-size:([0-9]*)pt([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)font-size:([0-9]*)pt([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("<span\\1\\3><font size=\"\\2\">\\4</span>" ) );
+			newMsg.replace( regExp, QStringLiteral("<span\\1\\3><font size=\"\\2\">\\4</span>" ) );
 		}
 	}
 
 	// remove span-tags
-	regExp.setPattern( "<span([^>]*)>(.*)</span>" );
+	regExp.setPattern( QStringLiteral("<span([^>]*)>(.*)</span>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("\\2") );
+			newMsg.replace( regExp, QStringLiteral("\\2") );
 		}
 	}
 
 	// remove p-tags
-	regExp.setPattern( "<p([^>]*)>(.*)</p>" );
+	regExp.setPattern( QStringLiteral("<p([^>]*)>(.*)</p>") );
 	pos = 0;
 	while ( pos >= 0 ) {
 		pos = regExp.indexIn( messageText, pos );
 		if ( pos >= 0 ) {
 			pos += regExp.matchedLength();
-			newMsg.replace( regExp, QLatin1String("\\2") );
+			newMsg.replace( regExp, QStringLiteral("\\2") );
 		}
 	}
 
@@ -346,19 +343,19 @@ QString YahooContact::prepareMessage( const QString &messageText )
 	newMsg.replace( QLatin1String( "&quot;" ), QLatin1String( "\"" ) );
 	newMsg.replace( QLatin1String( "&nbsp;" ), QLatin1String( " " ) );
 	newMsg.replace( QLatin1String( "&amp;" ), QLatin1String( "&" ) );
-	newMsg.replace( QRegExp( QString::fromLatin1("<br[ /]*>") ), QLatin1String( "\r" ) );
+	newMsg.replace( QRegExp( QLatin1String("<br[ /]*>") ), QStringLiteral( "\r" ) );
 
 	return newMsg;
 }
 
 void YahooContact::slotSendMessage( Kopete::Message &message )
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	QString messageText = message.escapedBody();
-	kDebug(YAHOO_GEN_DEBUG) << "Original message: " << messageText;
+	qCDebug(YAHOO_PROTOCOL_LOG) << "Original message: " << messageText;
 	messageText = prepareMessage( messageText );
-	kDebug(YAHOO_GEN_DEBUG) << "Converted message: " << messageText;
+	qCDebug(YAHOO_PROTOCOL_LOG) << "Converted message: " << messageText;
 
 	Kopete::ContactPtrList m_them = manager(Kopete::Contact::CanCreate)->members();
 	Kopete::Contact *target = m_them.first();
@@ -376,7 +373,7 @@ void YahooContact::slotSendMessage( Kopete::Message &message )
 	manager(Kopete::Contact::CanCreate)->messageSucceeded();
 }
 
-void YahooContact::sendFile( const KUrl &sourceURL, const QString &fileName, uint fileSize )
+void YahooContact::sendFile( const QUrl &sourceURL, const QString &fileName, uint fileSize )
 {
 	Kopete::TransferManager::transferManager()->sendFile( sourceURL, fileName, fileSize,
 			false, this, SLOT(slotSendFile(KUrl)) );
@@ -387,23 +384,22 @@ void YahooContact::slotTyping(bool isTyping_ )
 	Kopete::ContactPtrList m_them = manager(Kopete::Contact::CanCreate)->members();
 	Kopete::Contact *target = m_them.first();
 
-
 	m_account->yahooSession()->sendTyping( static_cast<YahooContact*>(target)->m_userId, isTyping_ );
 }
 
 void YahooContact::slotChatSessionDestroyed()
 {
-	m_manager = 0L;
+	m_manager = nullptr;
 	m_account->yahooSession()->setChatSessionState( m_userId, true );	// Unregister chatsession
 	m_sessionActive = false;
 }
 
-QList<KAction*> *YahooContact::customContextMenuActions()
+QList<QAction*> *YahooContact::customContextMenuActions()
 {
-	QList<KAction*> *actions = new QList<KAction*>();
+    QList<QAction*> *actions = new QList<QAction*>();
 	if ( !m_webcamAction )
 	{
-		m_webcamAction = new KAction( KIcon("webcamreceive"), i18n( "View &Webcam" ), this );
+        m_webcamAction = new QAction( QIcon::fromTheme(QStringLiteral("webcamreceive")), i18n( "View &Webcam" ), this );
 		connect( m_webcamAction, SIGNAL(triggered(bool)), this, SLOT(requestWebcam()) );
 	}
 	if ( isReachable() )
@@ -415,7 +411,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 
 	if( !m_inviteWebcamAction )
 	{
-		m_inviteWebcamAction = new KAction( KIcon("webcamsend"), i18n( "Invite to view your Webcam" ), this );
+        m_inviteWebcamAction = new QAction( QIcon::fromTheme(QStringLiteral("webcamsend")), i18n( "Invite to view your Webcam" ), this );
 		connect( m_inviteWebcamAction, SIGNAL(triggered(bool)), this, SLOT(inviteWebcam()) );
 	}
 	if ( isReachable() )
@@ -427,7 +423,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 
 	if ( !m_buzzAction )
 	{
-		m_buzzAction = new KAction( KIcon("bell"), i18n( "&Buzz Contact" ), this);
+        m_buzzAction = new QAction( QIcon::fromTheme(QStringLiteral("bell")), i18n( "&Buzz Contact" ), this);
 		connect( m_buzzAction, SIGNAL(triggered(bool)), this, SLOT(buzzContact()) );
 	}
 	if ( isReachable() )
@@ -439,7 +435,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 
 	if ( !m_stealthAction )
 	{
-		m_stealthAction = new KAction( KIcon("yahoo_stealthed"), i18n( "&Stealth Setting" ), this );
+        m_stealthAction = new QAction( QIcon::fromTheme(QStringLiteral("yahoo_stealthed")), i18n( "&Stealth Setting" ), this );
 		connect( m_stealthAction, SIGNAL(triggered(bool)), this, SLOT(stealthContact()) );
 	}
 	if ( isReachable() )
@@ -451,7 +447,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 
 	if ( !m_inviteConferenceAction )
 	{
-		m_inviteConferenceAction = new KAction( KIcon("x-office-contact"), i18n( "&Invite to Conference" ), this ); // icon should probably be "contact-invite", but that doesn't exist... please request an icon on http://techbase.kde.org/index.php?title=Projects/Oxygen/Missing_Icons
+        m_inviteConferenceAction = new QAction( QIcon::fromTheme(QStringLiteral("x-office-contact")), i18n( "&Invite to Conference" ), this ); // icon should probably be "contact-invite", but that doesn't exist... please request an icon on http://techbase.kde.org/index.php?title=Projects/Oxygen/Missing_Icons
 		connect( m_inviteConferenceAction, SIGNAL(triggered(bool)), this, SLOT(inviteConference()) );
 	}
 	if ( isReachable() )
@@ -463,7 +459,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 
 	if ( !m_profileAction )
 	{
-		m_profileAction = new KAction( KIcon("document-preview"), i18n( "&View Yahoo Profile" ), this );
+        m_profileAction = new QAction( QIcon::fromTheme(QStringLiteral("document-preview")), i18n( "&View Yahoo Profile" ), this );
 		connect( m_profileAction, SIGNAL(triggered(bool)), this, SLOT(slotUserProfile()) );
 	}
 	m_profileAction->setEnabled( true );
@@ -471,19 +467,19 @@ QList<KAction*> *YahooContact::customContextMenuActions()
         actions->append( m_profileAction );
 
 	// temporary action collection, used to apply Kiosk policy to the actions
-	KActionCollection tempCollection((QObject*)0);
-	tempCollection.addAction(QLatin1String("contactViewWebcam"), m_webcamAction);
-	tempCollection.addAction(QLatin1String("contactInviteToViewWebcam"), m_inviteWebcamAction);
-	tempCollection.addAction(QLatin1String("contactBuzz"), m_buzzAction);
-	tempCollection.addAction(QLatin1String("yahooContactStealth"), m_stealthAction);
-	tempCollection.addAction(QLatin1String("yahooContactInviteConference"), m_inviteConferenceAction);
-	tempCollection.addAction(QLatin1String("contactViewProfile"), m_profileAction);
+    KActionCollection tempCollection((QObject*)0);
+	tempCollection.addAction(QStringLiteral("contactViewWebcam"), m_webcamAction);
+	tempCollection.addAction(QStringLiteral("contactInviteToViewWebcam"), m_inviteWebcamAction);
+	tempCollection.addAction(QStringLiteral("contactBuzz"), m_buzzAction);
+	tempCollection.addAction(QStringLiteral("yahooContactStealth"), m_stealthAction);
+	tempCollection.addAction(QStringLiteral("yahooContactInviteConference"), m_inviteConferenceAction);
+	tempCollection.addAction(QStringLiteral("contactViewProfile"), m_profileAction);
 	return actions;
 }
 
 void YahooContact::slotUserInfo()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	if( !m_YABEntry )
 	{
 		readYABEntry();	// No YABEntry was set, so read the one from contactlist.xml
@@ -498,7 +494,7 @@ void YahooContact::slotUserInfo()
 
 void YahooContact::slotUserProfile()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	QString profileSiteString = QLatin1String("http://profiles.yahoo.com/") + userId();
 	KToolInvocation::invokeBrowser(  profileSiteString );
@@ -506,13 +502,13 @@ void YahooContact::slotUserProfile()
 
 void YahooContact::slotSendFile( const KUrl &url)
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	m_account->sendFile( this, url );
 }
 
 void YahooContact::stealthContact()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	QPointer <KDialog> stealthSettingDialog = new KDialog( Kopete::UI::Global::mainWidget() );
 	stealthSettingDialog->setCaption( i18n("Stealth Setting") );
@@ -534,7 +530,6 @@ void YahooContact::stealthContact()
 	if( stealthed() )
 		stealthWidget.radioPermOffline->setChecked( true );
 
-
 	// Show dialog
 	if ( stealthSettingDialog->exec() == QDialog::Rejected || ! stealthSettingDialog )
 	{
@@ -586,7 +581,7 @@ void YahooContact::buzzContact()
 
 void YahooContact::setDisplayPicture(const QByteArray &data, int checksum)
 {
-	kDebug(YAHOO_GEN_DEBUG) << data.size();
+	qCDebug(YAHOO_PROTOCOL_LOG) << data.size();
 
 	setProperty( YahooProtocol::protocol()->iconCheckSum, checksum );
 
@@ -605,10 +600,9 @@ void YahooContact::setDisplayPicture(const QByteArray &data, int checksum)
 	}
 }
 
-
 void YahooContact::setYABEntry( YABEntry *entry, bool show )
 {
-	kDebug(YAHOO_GEN_DEBUG) << userId();
+	qCDebug(YAHOO_PROTOCOL_LOG) << userId();
 	delete m_YABEntry;
 
 	m_YABEntry = entry;
@@ -701,20 +695,20 @@ void YahooContact::closeWebcamDialog()
 	if( m_receivingWebcam )
 		m_account->yahooSession()->closeWebcam( contactId() );
 	m_webcamDialog->delayedDestruct();
-	m_webcamDialog = 0L;
+	m_webcamDialog = nullptr;
 }
 
 void YahooContact::deleteContact()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	if( !m_account->isOnServer( contactId() ) )
 	{
-		kDebug(YAHOO_GEN_DEBUG) << "Contact does not exist on server-side. Not removing...";
+		qCDebug(YAHOO_PROTOCOL_LOG) << "Contact does not exist on server-side. Not removing...";
 	}
 	else
 	{
-		kDebug(YAHOO_GEN_DEBUG) << "Contact is getting remove from server side contact list....";
+		qCDebug(YAHOO_PROTOCOL_LOG) << "Contact is getting remove from server side contact list....";
 		// Delete from YAB first
 		if( !m_YABEntry )
 			readYABEntry();
@@ -728,7 +722,7 @@ void YahooContact::deleteContact()
 
 void YahooContact::writeYABEntry()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 
 	// Personal
 	setProperty( YahooProtocol::protocol()->propfirstName, m_YABEntry->firstName );
@@ -787,7 +781,7 @@ void YahooContact::writeYABEntry()
 
 void YahooContact::readYABEntry()
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
+	qCDebug(YAHOO_PROTOCOL_LOG) ;
 	delete m_YABEntry;
 
 	m_YABEntry = new YABEntry;
@@ -847,8 +841,5 @@ void YahooContact::readYABEntry()
 	m_YABEntry->additional4 = property( YahooProtocol::protocol()->propAdditional4 ).value().toString();
 }
 
-#include "yahoocontact.moc"
-
-// vim: set noet ts=4 sts=4 sw=4:
 //kate: space-indent off; replace-tabs off; indent-mode csands;
 
